"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const readDir = util_1.promisify(fs_1.default.readdir);
/**
 * Finds the first matched file in the given directory, ignoring the extension name.
 * EG:
 *     With a given directory of:
 *     dir/
 *         site.css
 *         site.scss
 *         home.scss
 *
 *     If findFile is called as `findFile('dir/', 'site')`
 *     then 'dir/site.css' would be returned (first result alphabetically)
 */
exports.default = async (dir, filename) => {
    const r = new RegExp(`^${filename}\.\\w+$`);
    const [file] = (await readDir(dir))
        .filter(f => fs_1.default.statSync(path_1.default.join(dir, f)).isFile())
        .filter(f => r.test(f));
    if (!file)
        return false;
    return path_1.default.join(dir, file);
};
