"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const util_1 = require("util");
const path_1 = __importDefault(require("path"));
const fsReadFile = util_1.promisify(fs_1.readFile);
const fsWriteFile = util_1.promisify(fs_1.writeFile);
const deepmerge_1 = __importDefault(require("deepmerge"));
const PKG_FILE = () => path_1.default.resolve(process.env.CLI_CWD || process.cwd(), 'package.json');
var pkgjson;
(function (pkgjson) {
    /**
     * Attempt to load the package.json at the current directory
     * @returns {NPM.Static|Boolean} The package as json, or false if it cannot be found
     * or loaded correctly
    */
    pkgjson.read = async () => {
        return new Promise((res, rej) => {
            fsReadFile(PKG_FILE())
                .catch(e => {
                res(false);
            })
                .then(json => {
                if (json)
                    res(json.toJSON());
                else
                    return false;
            });
        });
    };
    /**
     * Merge/create the package.json file
     * @param file JSON config for Origami app to override
     */
    pkgjson.write = async (file) => {
        let existing = {};
        try {
            existing = require(PKG_FILE());
        }
        catch (e) {
            // No existing package.json file
        }
        const TAB_SIZE = 4;
        return fsWriteFile(PKG_FILE(), JSON.stringify(deepmerge_1.default(existing, file), null, TAB_SIZE));
    };
})(pkgjson = exports.pkgjson || (exports.pkgjson = {}));
